bands_gradient — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bands_gradient

property ElectronicBandStructure.bands_gradient

  Bands gradient is a numpy array that stores each band gradient a list that corresponds to the self.kpoints Shape = [n_kpoints,3,n_bands], where the second dimension represents d/dx,d/dy,d/dz

  Returns:

    np.ndarray – Bands fradient is a numpy array that stores each band gradient in a list that corresponds to the self.kpoints Shape = [n_kpoints,3,n_bands], where the second dimension represents d/dx,d/dy,d/dz